@@ -11,7 +11,7 @@ package Perl7::Handy;
 use 5.00503;    # Universal Consensus 1998 for primetools
 # use 5.008001; # Lancaster Consensus 2013 for toolchains
 
-$VERSION = '0.06';
+$VERSION = '0.07';
 $VERSION = $VERSION;
 
 BEGIN { pop @INC if $INC[-1] eq '.' } # CVE-2016-1238: Important unsafe module load path flaw
@@ -267,6 +267,7 @@ sub STORE {
 #   no bareword::filehandles;
 #   no multidimensional;
 #   use feature qw(signatures); no warnings qw(experimental::signatures);
+#   no feature qw(indirect);
 sub import {
 
     # gives caller package "use strict;"
@@ -280,6 +281,12 @@ sub import {
         if ($] >= 5.020) {
             feature->import('signatures');
             warnings->unimport('experimental::signatures');
+
+            # disables indirect object syntax in caller package
+            # Bug #138701 for Perl7-Handy: Consider disabling indirect object notation [rt.cpan.org #138701]
+            if ($] >= 5.031009) {
+                feature->unimport('indirect');
+            }
         }
     }
 
@@ -333,6 +340,8 @@ Perl7::Handy module provides easy Perl7 scripting environment onto perl
 
 =item * gives caller package "use feature qw(signatures); no warnings qw(experimental::signatures);" (only perl 5.020 or later)
 
+=item * gives caller package "no feature qw(indirect); (only perl 5.031009 or later)
+
 =item * removes ".(dot)" from @INC (CVE-2016-1238: Important unsafe module load path flaw)
 
 =back
@@ -354,37 +363,85 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 =head1 SEE ALSO
 
-=over 4
-
-=item * L<Announcing Perl 7|https://www.perl.com/article/announcing-perl-7/> - perl.com
-
-=item * L<Import pragmas like strict and warnings into callers lexical scope|https://www.perlmonks.org/?node_id=887663> - perlmonks.org
-
-=item * L<Perl import some modules in all subclasses|https://stackoverflow.com/questions/22122390/perl-import-some-modules-in-all-subclasses> - stackoverflow.com
-
-=item * L<open|http://perldoc.perl.org/functions/open.html> - perldoc.perl.org
-
-=item * L<Three-arg open() (Migrating to Modern Perl)|http://modernperlbooks.com/mt/2010/04/three-arg-open-migrating-to-modern-perl.html> - modernperlbooks.com
-
-=item * L<perl - open my $fh, "comand (pipe)"; # isn't modern|http://blog.livedoor.jp/dankogai/archives/51176081.html> - 404 Blog Not Found
-
-=item * L<13.15. Creating Magic Variables with tie|https://docstore.mik.ua/orelly/perl3/cookbook/ch13_16.htm> - Perl Cookbook
-
-=item * L<13.15. Creating Magic Variables with tie|https://docstore.mik.ua/orelly/perl4/cook/ch13_16.htm> - Perl Cookbook, 2nd Edition
-
-=item * L<CVE-2016-1238|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-1238> - CVE
-
-=item * L<CVE-2016-1238: Important unsafe module load path flaw|https://www.nntp.perl.org/group/perl.perl5.porters/2016/07/msg238271.html> - perl.org
-
-=item * L<signatures - Subroutine signatures with no source filter|https://metacpan.org/release/signatures> - CPAN
-
-=item * L<indirect - Lexically warn about using the indirect method call syntax.|https://metacpan.org/release/indirect> - CPAN
-
-=item * L<ina|http://search.cpan.org/~ina/> - cpan.org
-
-=item * L<BackPAN|http://backpan.perl.org/authors/id/I/IN/INA/> - backpan.perl.org
-
-=back
+ Announcing Perl 7
+ https://www.perl.com/article/announcing-perl-7/
+ 
+ Perl 7 is coming
+ https://www.effectiveperlprogramming.com/2020/06/perl-7-is-coming/
+ 
+ A vision for Perl 7 and beyond
+ https://xdg.me/a-vision-for-perl-7-and-beyond/
+ 
+ On Perl 7 and the Perl Steering Committee
+ https://lwn.net/Articles/828384/
+ 
+ Perl7 and the future of Perl
+ http://www.softpanorama.org/Scripting/Language_wars/perl7_and_the_future_of_perl.shtml
+ 
+ Perl 7: A Risk-Benefit Analysis
+ http://blogs.perl.org/users/grinnz/2020/07/perl-7-a-risk-benefit-analysis.html
+ 
+ Perl 7 By Default
+ http://blogs.perl.org/users/grinnz/2020/08/perl-7-by-default.html
+ 
+ Perl 7: A Modest Proposal
+ https://dev.to/grinnz/perl-7-a-modest-proposal-434m
+ 
+ Perl 7 FAQ
+ https://gist.github.com/Grinnz/be5db6b1d54b22d8e21c975d68d7a54f
+ 
+ Perl 7, not quite getting better yet
+ http://blogs.perl.org/users/leon_timmermans/2020/06/not-quite-getting-better-yet.html
+ 
+ Re: Announcing Perl 7
+ https://www.nntp.perl.org/group/perl.perl5.porters/2020/06/msg257566.html
+ https://www.nntp.perl.org/group/perl.perl5.porters/2020/06/msg257568.html
+ https://www.nntp.perl.org/group/perl.perl5.porters/2020/06/msg257572.html
+ 
+ Changed defaults - Are they best for newbies?
+ https://www.nntp.perl.org/group/perl.perl5.porters/2020/08/msg258221.html
+ 
+ A vision for Perl 7 and beyond
+ https://web.archive.org/web/20200927044106/https://xdg.me/archive/2020-a-vision-for-perl-7-and-beyond/
+ 
+ Import pragmas like strict and warnings into callers lexical scope
+ https://www.perlmonks.org/?node_id=887663
+ 
+ Perl import some modules in all subclasses
+ https://stackoverflow.com/questions/22122390/perl-import-some-modules-in-all-subclasses
+ 
+ open
+ http://perldoc.perl.org/functions/open.html
+ 
+ Three-arg open() (Migrating to Modern Perl)
+ http://modernperlbooks.com/mt/2010/04/three-arg-open-migrating-to-modern-perl.html
+ 
+ perl - open my $fh, "comand (pipe)"; # isn't modern
+ http://blog.livedoor.jp/dankogai/archives/51176081.html
+ 
+ 13.15. Creating Magic Variables with tie - Perl Cookbook
+ https://docstore.mik.ua/orelly/perl3/cookbook/ch13_16.htm
+ 
+ 13.15. Creating Magic Variables with tie - Perl Cookbook, 2nd Edition
+ https://docstore.mik.ua/orelly/perl4/cook/ch13_16.htm
+ 
+ CVE-2016-1238 - CVE
+ https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-1238
+ 
+ CVE-2016-1238: Important unsafe module load path flaw
+ https://www.nntp.perl.org/group/perl.perl5.porters/2016/07/msg238271.html
+ 
+ signatures - Subroutine signatures with no source filter
+ https://metacpan.org/release/signatures
+ 
+ indirect - Lexically warn about using the indirect method call syntax.
+ https://metacpan.org/release/indirect
+ 
+ ina
+ http://search.cpan.org/~ina/
+ 
+ BackPAN
+ http://backpan.perl.org/authors/id/I/IN/INA/
 
 =cut
 
